package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.ElecStoreH;

/**
 * 储能计量-小时Service接口
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
public interface IElecStoreHService
{
    /**
     * 查询储能计量-小时
     * 
     * @param id 储能计量-小时主键
     * @return 储能计量-小时
     */
     ElecStoreH selectElecStoreHById(Long id);

    /**
     * 查询储能计量-小时列表
     * 
     * @param elecStoreH 储能计量-小时
     * @return 储能计量-小时集合
     */
     List<ElecStoreH> selectElecStoreHList(ElecStoreH elecStoreH);

    /**
     * 新增储能计量-小时
     * 
     * @param elecStoreH 储能计量-小时
     * @return 结果
     */
     int insertElecStoreH(ElecStoreH elecStoreH);

    /**
     * 修改储能计量-小时
     * 
     * @param elecStoreH 储能计量-小时
     * @return 结果
     */
     int updateElecStoreH(ElecStoreH elecStoreH);

    /**
     * 批量删除储能计量-小时
     * 
     * @param ids 需要删除的储能计量-小时主键集合
     * @return 结果
     */
     int deleteElecStoreHByIds(Long[] ids);

    /**
     * 删除储能计量-小时信息
     * 
     * @param id 储能计量-小时主键
     * @return 结果
     */
     int deleteElecStoreHById(Long id);
}
